[tarantool-patches] [PATCH v3] Fix warnings

Gleb dmarc-noreply at freelists.org
Wed Apr 18 20:08:21 MSK 2018


Ensure -Werror -Wall set for the whole src/.
Fix warnings which have been found with -Werror and -Wall.
Add new build target RelWithDebInfoWError.
Change build target on RelWithDebInfoWError in CI.

Fixes #3238
---
Issue from https://github.com/tarantool/tarantool/issues/3238.
Source from https://github.com/tarantool/tarantool/tree/gh-3238-check-warnings.
 .travis.mk                 |  4 ++--
 cmake/compiler.cmake       |  8 +++++++-
 src/box/space_def.c        |  2 ++
 src/box/sql/CMakeLists.txt |  3 ---
 src/box/sql/alter.c        |  1 +
 src/box/sql/insert.c       |  5 +++--
 src/box/sql/pragma.c       |  4 ++--
 src/box/vy_read_iterator.c |  2 +-
 src/box/xrow.c             | 10 +++++++---
 src/httpc.c                |  2 +-
 src/lua/init.c             |  3 ++-
 src/say.c                  |  6 ++++--
 12 files changed, 32 insertions(+), 18 deletions(-)

diff --git a/.travis.mk b/.travis.mk
index 393d78f..2328e0d 100644
--- a/.travis.mk
+++ b/.travis.mk
@@ -40,7 +40,7 @@ deps_ubuntu:
 		lcov ruby tcl
 
 test_ubuntu: deps_ubuntu
-	cmake . -DCMAKE_BUILD_TYPE=RelWithDebInfo
+	cmake . -DCMAKE_BUILD_TYPE=RelWithDebInfoWError
 	make -j8
 	cd test && /usr/bin/python test-run.py -j -1
 
@@ -49,7 +49,7 @@ deps_osx:
 	brew install openssl readline curl icu4c --force
 
 test_osx: deps_osx
-	cmake . -DCMAKE_BUILD_TYPE=RelWithDebInfo
+	cmake . -DCMAKE_BUILD_TYPE=RelWithDebInfoWError
 	# Increase the maximum number of open file descriptors on macOS
 	sudo sysctl -w kern.maxfiles=20480 || :
 	sudo sysctl -w kern.maxfilesperproc=20480 || :
diff --git a/src/box/space_def.c b/src/box/space_def.c
index 22bd3ca..3f11088 100644
--- a/src/box/space_def.c
+++ b/src/box/space_def.c
@@ -130,6 +130,7 @@ space_def_dup(const struct space_def *src)
 				 * allocation refactoring.
 				 */
 				assert(expr_pos_old == expr_pos);
+				(void) expr_pos_old;
 				expr_pos += sql_expr_sizeof(e, 0);
 				ret->fields[i].default_value_expr = e;
 			}
@@ -216,6 +217,7 @@ space_def_new(uint32_t id, uint32_t uid, uint32_t exact_field_count,
 				 * allocation refactoring.
 				 */
 				assert(expr_pos_old == expr_pos);
+				(void) expr_pos_old;
 				expr_pos += sql_expr_sizeof(e, 0);
 				def->fields[i].default_value_expr = e;
 			}
diff --git a/src/box/sql/CMakeLists.txt b/src/box/sql/CMakeLists.txt
index 678eb4c..526d9fe 100644
--- a/src/box/sql/CMakeLists.txt
+++ b/src/box/sql/CMakeLists.txt
@@ -4,9 +4,6 @@ if(CMAKE_BUILD_TYPE STREQUAL "Debug")
   add_definitions(-DSQLITE_DEBUG=1)
   add_definitions(-DSQLITE_ENABLE_SELECTTRACE)
   add_definitions(-DSQLITE_ENABLE_WHERETRACE)
-
-  set(CMAKE_C_FLAGS "${CMAKE_C_FLAGS} -Wall -Wextra -Werror")
-  set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -Wall -Wextra -Werror")
 endif()
 
 set(SRCDIR ${CMAKE_CURRENT_SOURCE_DIR})
diff --git a/src/box/sql/alter.c b/src/box/sql/alter.c
index 129ef82..5f553c8 100644
--- a/src/box/sql/alter.c
+++ b/src/box/sql/alter.c
@@ -156,6 +156,7 @@ sqlite3AlterFinishAddColumn(Parse * pParse, Token * pColDef)
 	if (pParse->nErr || db->mallocFailed)
 		return;
 	assert(v != 0);
+	(void) v;
 	pNew = pParse->pNewTable;
 	assert(pNew);
 
diff --git a/src/box/sql/insert.c b/src/box/sql/insert.c
index b24d55b..e54c9fe 100644
--- a/src/box/sql/insert.c
+++ b/src/box/sql/insert.c
@@ -47,15 +47,16 @@ sqlite3OpenTable(Parse * pParse,	/* Generate code into this VDBE */
 		 Table * pTab,	/* The table to be opened */
 		 int opcode)	/* OP_OpenRead or OP_OpenWrite */
 {
-	Vdbe *v;
-	v = sqlite3GetVdbe(pParse);
+	Vdbe *v = sqlite3GetVdbe(pParse);
 	assert(opcode == OP_OpenWrite || opcode == OP_OpenRead);
+	(void) opcode;
 	Index *pPk = sqlite3PrimaryKeyIndex(pTab);
 	assert(pPk != 0);
 	assert(pPk->tnum == pTab->tnum);
 	emit_open_cursor(pParse, iCur, pPk->tnum);
 	sqlite3VdbeSetP4KeyInfo(pParse, pPk);
 	VdbeComment((v, "%s", pTab->zName));
+	(void) v;
 }
 
 /*
diff --git a/src/box/sql/pragma.c b/src/box/sql/pragma.c
index b724c98..be973b7 100644
--- a/src/box/sql/pragma.c
+++ b/src/box/sql/pragma.c
@@ -256,7 +256,6 @@ sqlite3Pragma(Parse * pParse, Token * pId,	/* First part of [schema.]id field */
 	char *zLeft = 0;	/* Nul-terminated UTF-8 string <id> */
 	char *zRight = 0;	/* Nul-terminated UTF-8 string <value>, or NULL */
 	char *zTable = 0;	/* Nul-terminated UTF-8 string <value2> or NULL */
-	int rc;			/* return value form SQLITE_FCNTL_PRAGMA */
 	sqlite3 *db = pParse->db;	/* The database connection */
 	Vdbe *v = sqlite3GetVdbe(pParse);	/* Prepared statement */
 	const PragmaName *pPragma;	/* The pragma */
@@ -516,8 +515,9 @@ sqlite3Pragma(Parse * pParse, Token * pId,	/* First part of [schema.]id field */
 		box_tuple_t *tuple;
 		box_iterator_t* iter;
 		iter = box_index_iterator(space_id, 0,ITER_ALL, key_buf, key_end);
-		rc = box_iterator_next(iter, &tuple);
+		int rc = box_iterator_next(iter, &tuple);
 		assert(rc==0);
+		(void) rc;
 		for (i = 0; tuple!=NULL; i++, box_iterator_next(iter, &tuple)){
 			/* 1 is name field number */
 			const char *str = tuple_field_cstr(tuple, 1);
diff --git a/src/box/vy_read_iterator.c b/src/box/vy_read_iterator.c
index 2cad233..fea2c46 100644
--- a/src/box/vy_read_iterator.c
+++ b/src/box/vy_read_iterator.c
@@ -552,7 +552,7 @@ vy_read_iterator_next_lsn(struct vy_read_iterator *itr, struct tuple **ret)
 {
 	uint32_t i;
 	bool unused;
-	struct vy_read_src *src;
+	struct vy_read_src *src = NULL;
 
 	assert(itr->curr_stmt != NULL);
 	assert(itr->curr_src < itr->skipped_src);
diff --git a/src/box/xrow.c b/src/box/xrow.c
index 3ef3d82..29f2496 100644
--- a/src/box/xrow.c
+++ b/src/box/xrow.c
@@ -302,6 +302,7 @@ iproto_reply_vclock(struct obuf *out, uint64_t sync, uint32_t schema_version,
 
 	char *ptr = obuf_alloc(out, size);
 	assert(ptr == buf);
+	(void) ptr;
 	return 0;
 }
 
@@ -339,9 +340,12 @@ iproto_write_error(int fd, const struct error *e, uint32_t schema_version,
 			     schema_version, sizeof(body) + msg_len);
 
 	body.v_data_len = mp_bswap_u32(msg_len);
-	(void) write(fd, header, sizeof(header));
-	(void) write(fd, &body, sizeof(body));
-	(void) write(fd, e->errmsg, msg_len);
+	ssize_t unused1 = write(fd, header, sizeof(header));
+	ssize_t unused2 = write(fd, &body, sizeof(body));
+	ssize_t unused3 = write(fd, e->errmsg, msg_len);
+	(void) unused1; /* silence gcc warning */
+	(void) unused2; /* silence gcc warning */
+	(void) unused3; /* silence gcc warning */
 }
 
 int
diff --git a/src/httpc.c b/src/httpc.c
index 633e688..a720cf3 100644
--- a/src/httpc.c
+++ b/src/httpc.c
@@ -249,7 +249,7 @@ httpc_set_low_speed_limit(struct httpc_request *req, long low_speed_limit)
 void
 httpc_set_verbose(struct httpc_request *req, bool curl_verbose)
 {
-	curl_easy_setopt(req->curl_request.easy, CURLOPT_VERBOSE, curl_verbose);
+	curl_easy_setopt(req->curl_request.easy, CURLOPT_VERBOSE, (long) curl_verbose);
 }
 
 void
diff --git a/src/lua/init.c b/src/lua/init.c
index 76e978c..75b597a 100644
--- a/src/lua/init.c
+++ b/src/lua/init.c
@@ -279,7 +279,8 @@ tarantool_lua_setpaths(struct lua_State *L)
 {
 	const char *home = getenv("HOME");
 	char cwd[PATH_MAX] = {'\0'};
-	getcwd(cwd, sizeof(cwd));
+	char *unused = getcwd(cwd, sizeof(cwd));
+	(void) unused; /* silence gcc warning */
 	lua_getglobal(L, "package");
 	int top = lua_gettop(L);
 
diff --git a/src/say.c b/src/say.c
index 4312408..41e475d 100644
--- a/src/say.c
+++ b/src/say.c
@@ -1130,8 +1130,10 @@ log_vsay(struct log *log, int level, const char *filename, int line,
 		break;
 	case SAY_LOGGER_SYSLOG:
 		write_to_syslog(log, total);
-		if (level == S_FATAL && log->fd != STDERR_FILENO)
-			(void) safe_write(STDERR_FILENO, buf, total);
+		if (level == S_FATAL && log->fd != STDERR_FILENO) {
+			ssize_t unused = safe_write(STDERR_FILENO, buf, total);
+			(void) unused; /* silence gcc warning */
+		}
 		break;
 	case SAY_LOGGER_BOOT:
 	{
diff --git a/cmake/compiler.cmake b/cmake/compiler.cmake
index 05d33ab..12fc335 100644
--- a/cmake/compiler.cmake
+++ b/cmake/compiler.cmake
@@ -251,12 +251,18 @@ macro(enable_tnt_compile_flags)
     add_definitions("-D__STDC_LIMIT_MACROS=1")
     add_definitions("-D__STDC_CONSTANT_MACROS=1")
 
     # Only add -Werror if it's a debug build, done by developers.
     # Release builds should not cause extra trouble.
     if ((${CMAKE_BUILD_TYPE} STREQUAL "Debug")
         AND HAVE_STD_C11 AND HAVE_STD_CXX11)
         add_compile_flags("C;CXX" "-Werror")
     endif()
+
+    if ((${CMAKE_BUILD_TYPE} STREQUAL "RelWithDebInfoWError")
+        AND HAVE_STD_C11 AND HAVE_STD_CXX11)
+        add_compile_flags("C;CXX" "-Werror")
+    endif()
 endmacro(enable_tnt_compile_flags)
 
 if (HAVE_OPENMP)
@@ -251,12 +251,18 @@ macro(enable_tnt_compile_flags)
     add_definitions("-D__STDC_CONSTANT_MACROS=1")
 
-    # Only add -Werror if it's a debug build, done by developers.
+    # Only add -Werror if it's a Debug or
+    # RelWithDebInfoWError build, done by developers.
     # Release builds should not cause extra trouble.
     if ((${CMAKE_BUILD_TYPE} STREQUAL "Debug")
-- 
2.7.4





More information about the Tarantool-patches mailing list